Documentation
¶
Overview ¶
Package flutter provides Flutter project configuration and means of parsing it from the filesystem.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrNoPubspec = errors.New("no pubspec.yaml found in the current or any parent directory")
Functions ¶
This section is empty.
Types ¶
type FlutterConfig ¶
FlutterConfig represents a Flutter project configuration.
func NewFromDirectory ¶
func NewFromDirectory(dir string) (*FlutterConfig, error)
NewFromDirectory creates a FlutterConfig if the given dir was inside a Flutter project or nil otherwise.
type L10n ¶
type L10n struct {
ARBDir string `yaml:"arb-dir"`
TemplateArbFile string `yaml:"template-arb-file"`
RequireResourceAttributes bool `yaml:"required-resource-attributes"`
POEditorProjectID string `yaml:"poeditor-project-id"`
POEditorLangs []string `yaml:"poeditor-langs"`
}
L10n represents the l10n.yaml configuration file in a Flutter project directory.
Click to show internal directories.
Click to hide internal directories.